@@ -25,7 +25,7 @@ def get_token(username, password):
     :param password: 密码
     :return: 返回 token 的值
     """
-    url = '{}/authority/manage/user/login'.format(auth_url)
+    url = '{}/sso/login'.format(auth_url)
     payload = json.dumps({
         "password": password,
         "username": username
@@ -64,34 +64,34 @@ def token_validate(jwt_token):
     return is_valid
 
 
-@cached(timeout=60*10)
-def access_system(jwt_token):
-    """
-    判断用户是否有此系统的访问权限
-    :param jwt_token: 'Bearer ...'
-    :return: 返回 True 或者 False
-    """
+# @cached(timeout=60*10)
+# def access_system(jwt_token):
+#     """
+#     判断用户是否有此系统的访问权限
+#     :param jwt_token: 'Bearer ...'
+#     :return: 返回 True 或者 False
+#     """
 
-    system_id = getattr(settings, 'AIIT_SYSTEM_ID')
-    if not system_id:
-        system_id = settings.ROOT_URLCONF.split('.')[0]
-    url = "{}/authority/manage/user/verify/access/system".format(auth_url)
-    payload = json.dumps(
-        {
-            "systemId": system_id,
-            "token": jwt_token,
-        }
-    )
-    headers = {
-        'Authorization': jwt_token,
-        'Content-Type': 'application/json'
-    }
-    response = requests.request("POST", url, headers=headers, data=payload)
-    is_valid = False
-    if response.status_code == 200:
-        res_json = response.json()
-        is_valid = res_json.get('result', {}).get('access', False)
-    return is_valid
+#     system_id = getattr(settings, 'AIIT_SYSTEM_ID')
+#     if not system_id:
+#         system_id = settings.ROOT_URLCONF.split('.')[0]
+#     url = "{}/authority/manage/user/verify/access/system".format(auth_url)
+#     payload = json.dumps(
+#         {
+#             "systemId": system_id,
+#             "token": jwt_token,
+#         }
+#     )
+#     headers = {
+#         'Authorization': jwt_token,
+#         'Content-Type': 'application/json'
+#     }
+#     response = requests.request("POST", url, headers=headers, data=payload)
+#     is_valid = False
+#     if response.status_code == 200:
+#         res_json = response.json()
+#         is_valid = res_json.get('result', {}).get('access', False)
+#     return is_valid
 
 
 @cached(timeout=60*30)
@@ -144,8 +144,9 @@ class AiitToken(UntypedToken):
         is_valid = token_validate('Bearer {}'.format(self.token.decode()))
         if not is_valid:
             raise TokenError(_('token 无效'))
-        system_access_check = getattr(settings, 'AIIT_SYSTEM_ACCESS', False)
-        if system_access_check:
-            can_access = access_system('Bearer {}'.format(self.token.decode()))
-            if not can_access:
-                raise TokenError(_('无权访问，请联系管理员'))
+        
+        #system_access_check = getattr(settings, 'AIIT_SYSTEM_ACCESS', False)
+        #if system_access_check:
+            #can_access = access_system('Bearer {}'.format(self.token.decode()))
+            #if not can_access:
+                #raise TokenError(_('无权访问，请联系管理员'))
